==> apache-ignite-2.5.0-src.zip: apache-ignite-2.5.0-src/modules/core/src/main/java/org/apache/ignite/internal/pagemem/wal/record/MetastoreDataRecord.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

package org.apache.ignite.internal.pagemem.wal.record;

import org.apache.ignite.internal.util.typedef.internal.S;
import org.jetbrains.annotations.Nullable;

/**
 *
 */
public class MetastoreDataRecord extends WALRecord {
    /** */
    private final String key;

    /** */
    @Nullable private final byte[] value;

    /**
     * @param key Key.
     * @param value Value.
     */
    public MetastoreDataRecord(String key, @Nullable byte[] value) {
        this.key = key;
        this.value = value;
    }

    /** */
    public String key() {
        return key;
    }

    /** */
    @Nullable public byte[] value() {
        return value;
    }

    /** {@inheritDoc} */
    @Override public RecordType type() {
        return RecordType.METASTORE_DATA_RECORD;
    }

    /** {@inheritDoc} */
    @Override public String toString() {
        return S.toString(MetastoreDataRecord.class, this, "super", super.toString());
    }
}

==> apache-ignite-2.8.1-src.zip: apache-ignite-2.8.1-src/modules/core/src/main/java/org/apache/ignite/internal/pagemem/wal/record/MetastoreDataRecord.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

package org.apache.ignite.internal.pagemem.wal.record;

import org.apache.ignite.internal.processors.cache.persistence.metastorage.MetaStorage;
import org.apache.ignite.internal.util.typedef.internal.S;
import org.jetbrains.annotations.Nullable;

/**
 *
 */
public class MetastoreDataRecord extends WALRecord implements WalRecordCacheGroupAware {
    /** */
    private final String key;

    /** */
    @Nullable private final byte[] value;

    /**
     * @param key Key.
     * @param value Value.
     */
    public MetastoreDataRecord(String key, @Nullable byte[] value) {
        this.key = key;
        this.value = value;
    }

    /** */
    public String key() {
        return key;
    }

    /** */
    @Nullable public byte[] value() {
        return value;
    }

    /** {@inheritDoc} */
    @Override public RecordType type() {
        return RecordType.METASTORE_DATA_RECORD;
    }

    /** {@inheritDoc} */
    @Override public String toString() {
        return S.toString(MetastoreDataRecord.class, this, "super", super.toString());
    }

    /** {@inheritDoc} */
    @Override public int groupId() {
        return MetaStorage.METASTORAGE_CACHE_ID;
    }
}
